@@ -1,5 +1,4 @@
-use actix_service::Service;
-use actix_web::{get, http::StatusCode, test, web, App, HttpResponse, ResponseError};
+use actix_web::{dev::Service, get, http::StatusCode, test, web, App, HttpResponse, ResponseError};
 use maplit::hashmap;
 use pretty_assertions::assert_eq;
 use serde_json::json;
